==> muitv-0.4.0.tgz: package/src/components/demo/ConsumptionAutoDemo.js <==
import React, {Component} from "react";

import ConsumptionAuto from "components/layouts/ConsumptionAuto";

import LinearProgress from "@material-ui/core/LinearProgress";
import {withStyles} from "@material-ui/core/styles";
import IconButton from "@material-ui/core/IconButton";
import DeleteIcon from "@material-ui/icons/Delete";

const styles = theme => ({
  button1: {
    marginTop: 10,
    marginLeft: theme.spacing.unit * 2,
    marginRight: theme.spacing.unit * 2,
    height: '2em',
    width: '2em'
  },
  icon1: {
    width: '1em',
    height: '1em'
  },
  button2: {
    marginTop: 10,
    marginLeft: theme.spacing.unit * 4,
    marginRight: theme.spacing.unit * 4,
    height: '2.6em',
    width: '2.6em'
  },
  icon2: {
    width: '1.3em',
    height: '1.3em'
  },
  button3: {
    marginTop: 10,
    marginLeft: theme.spacing.unit * 6,
    marginRight: theme.spacing.unit * 6,
    height: '4em',
    width: '4em'
  },
  icon3: {
    width: '2em',
    height: '2em'
  }
});

class ConsumptionAutoDemo extends Component {
  render() {
    const ih = window.innerHeight;
    const {classes} = this.props;
    const title = "Consumption Auto With a very long title that should wrap";
    const subtitle = "Demo";
    const leftValue = "35:00";
    const rightValue = "1:40:00";
    const progress = <LinearProgress variant="determinate" value={35}/>;

    const buttonClass = ih > 700
      ? classes.button3
      : ih > 395
        ? classes.button2
        : classes.button1;
    const iconClass = ih > 700
      ? classes.icon3
      : ih > 395
        ? classes.icon2
        : classes.icon1;

    // HACK: from the sizes being rendered

    const firstActionButtons = [
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton variant="fab" color="secondary" className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>
    ];

    const secondActionButtons = [
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>
    ];

    const art = "http://via.placeholder.com/400x400";
    const artSize = 400;

    const buttonClasses = {
      button1: classes.button1,
      icon1: classes.icon1,
      button2: classes.button2,
      icon2: classes.icon2,
      button3: classes.button3,
      icon3: classes.icon3
    }

    const cprops = {
      buttonClasses,
      title,
      subtitle,
      progress,
      firstActionButtons,
      secondActionButtons,
      leftValue,
      rightValue,
      art,
      artSize
    };

    return <ConsumptionAuto {...cprops}/>;
  }
}

export default withStyles(styles)(ConsumptionAutoDemo);

==> muitv-0.6.1.tgz: package/src/components/demo/ConsumptionAutoDemo.js <==
import React, {Component} from "react";

import ConsumptionAuto from "components/layouts/ConsumptionAuto";

import LinearProgress from "@material-ui/core/LinearProgress";
import {withStyles} from "@material-ui/core/styles";
import IconButton from "@material-ui/core/IconButton";
import DeleteIcon from "@material-ui/icons/Delete";

const styles = theme => ({
  button1: {
    marginTop: 10,
    marginLeft: theme.spacing(2),
    marginRight: theme.spacing(2),
    height: '2em',
    width: '2em'
  },
  icon1: {
    width: '1em',
    height: '1em'
  },
  button2: {
    marginTop: 10,
    marginLeft: theme.spacing(4),
    marginRight: theme.spacing(4),
    height: '2.6em',
    width: '2.6em'
  },
  icon2: {
    width: '1.3em',
    height: '1.3em'
  },
  button3: {
    marginTop: 10,
    marginLeft: theme.spacing(6),
    marginRight: theme.spacing(6),
    height: '4em',
    width: '4em'
  },
  icon3: {
    width: '2em',
    height: '2em'
  }
});

class ConsumptionAutoDemo extends Component {
  render() {
    const ih = window.innerHeight;
    const {classes} = this.props;
    const title = "Consumption Auto With a very long title that should wrap";
    const subtitle = "Demo";
    const leftValue = "35:00";
    const rightValue = "1:40:00";
    const progress = <LinearProgress variant="determinate" value={35}/>;

    const buttonClass = ih > 700
      ? classes.button3
      : ih > 395
        ? classes.button2
        : classes.button1;
    const iconClass = ih > 700
      ? classes.icon3
      : ih > 395
        ? classes.icon2
        : classes.icon1;

    // HACK: from the sizes being rendered

    const firstActionButtons = [
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton variant="fab" color="secondary" className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>
    ];

    const secondActionButtons = [
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass}/>
      </IconButton>
    ];

    const art = "http://via.placeholder.com/400x400";
    const artSize = 400;

    const buttonClasses = {
      button1: classes.button1,
      icon1: classes.icon1,
      button2: classes.button2,
      icon2: classes.icon2,
      button3: classes.button3,
      icon3: classes.icon3
    }

    const cprops = {
      buttonClasses,
      title,
      subtitle,
      progress,
      firstActionButtons,
      secondActionButtons,
      leftValue,
      rightValue,
      art,
      artSize
    };

    return <ConsumptionAuto {...cprops}/>;
  }
}

export default withStyles(styles)(ConsumptionAutoDemo);
